@@ -20,8 +20,7 @@
 Root of pytilities, various utilities
 
 Web site: http://pytilities.sourceforge.net/
-Project site with svn, ...: http://sourceforge.net/projects/pytilities/
-Releases: TODO (PyPI link)
+Sourceforge site: http://sourceforge.net/projects/pytilities/
 
 Features:
 
@@ -29,12 +28,12 @@ Features:
     target object without having to write those attributes on the decorating
     class
 
-    - event dispatching: Observer/Listener like event dispatching with wrappers
+    - event dispatching: Observer/Subject like event dispatching with wrappers
     for hiding events on dispatchers and combining dispatchers
 
     - function overloading
 
-    - various: a NumberType (anything numeric), a mangle function, ...
+    - various: Vector, Rectangle classes, custom types, ...
 
 Classes:
 
@@ -52,5 +51,5 @@ __docformat__ = 'reStructuredText'
 from .attributecollection import AttributeCollection
 from .attributecollectionbase import AttributeCollectionBase
 from .stringifiable import Stringifiable
-from .mangle import mangle
+from .mangling import mangle
 
