@@ -18,22 +18,17 @@
 
 __docformat__ = 'reStructuredText'
 
-from .profile import Profile
-from .delegator import Delegator
+from . import Profile, Delegator
 
 class DelegatorFactory(object):
     """
     Allows easy creation of delegators with `Profile`s.
-    
-    It also supports a form of inheritance. By specifying base
-    factories, a factory extends its bases' profiles (it takes the union of all
-    base profiles and its own). Using the inheritance you can add new profiles
-    and add attributes to existing profiles; you cannot, however, override
-    attributes.
 
+    By default already has a default profile.
+    
     Instance methods:
 
-        - `add_delegator_profile`: Add a `Profile`
+        - `set_profile`: Add/replace a `Profile`
         - `Delegator`: Construct a `Delegator` from a stored profile
         - `has_profile`: See if we have a particular profile
         - `get_profile`: Get profile by name
@@ -41,23 +36,15 @@ class DelegatorFactory(object):
     Class invariants:
 
         - Every profile has a unique name
+        - There's always a name='default' profile
     """
 
-    def __init__(self, bases=()):
-        """
-        Construct a `DelegatorFactory`, optionally with bases to inherit from.
-        
-        Parameters:
+    def __init__(self):
+        self.__profiles = {'default': Profile()}
 
-            `bases` :: (::DelegatorFactory...)
-                base factories for the created factory
+    def set_profile(self, name, profile):
         """
-        self.__bases = bases
-        self.__profiles = {}
-
-    def add_delegator_profile(self, name, profile):
-        """
-        Add a new delegator factory `Profile` to the factory.
+        Add/replace a delegator factory `Profile` to/on the factory.
 
         Parameters:
 
@@ -65,12 +52,8 @@ class DelegatorFactory(object):
                 name of the profile
 
             `profile` :: Profile
-                the profile to add
+                the profile for addition/replacement
         """
-        assert name not in self.__profiles, \
-                "Tried to add profile that's already added to this list." + \
-                " A DelegatorFactory cannot contain the same profile twice"
-
         self.__profiles[name] = profile
 
     def Delegator(self, profile_name = "default", target=None):
@@ -105,10 +88,6 @@ class DelegatorFactory(object):
         Returns True if the factory can find a profile by that name, False
         otherwise
         """
-        for base in self.__bases:
-            if base.has_profile(name):
-                return True
-
         return name in self.__profiles
 
     def get_profile(self, name):
@@ -120,26 +99,13 @@ class DelegatorFactory(object):
             `name` :: string
                 name of the profile
 
-        Returns profile by name, taking into account base factories' profiles 
-        :: Profile
+        Returns bound profile by name :: Profile
 
         Raises:
             - `ValueError` when profile isn't found
         """
-        profile = Profile()
-        found = False  # whether we have found the profile, anywhere
-
-        if name in self.__profiles:
-            profile |= self.__profiles[name]
-            found = True
-
-        for base in self.__bases:
-            if base.has_profile(name):
-                profile |= base.get_profile(name)
-                found = True
-
-        if not found:
+        try:
+            return self.__profiles[name]
+        except KeyError:
             raise ValueError("Failed to find profile: %s" % name)
 
-        return profile
-
