@@ -41,7 +41,7 @@ Decorators:
 
 __docformat__ = 'reStructuredText'
 
-from .dispatcher import Dispatcher, UnsupportedEventError
+from .dispatcher_ import Dispatcher, UnsupportedEventError
 from .dispatcherswitch import DispatcherSwitch
 from .restricteddispatcher import RestrictedDispatcher
 from .decorators import dispatcher, dispatcher_switch
