@@ -72,6 +72,3 @@ class DisturbanceTestCase(unittest.TestCase):
         d.x = 3
         self.assertEquals(d.x, 3)
 
-def run():
-    unittest.main(__name__)
-
